package internal

import (
	"codeup.aliyun.com/6552e56cc3b2728a4557fc18/plugin/proto"
	"encoding/json"
	"plugins/union_pay/internal/po"
)

type Config struct {
	Config *proto.Config
	Extra  *ConfigExtra
}

type ConfigExtra struct {
	ChNlId string `json:"chnlId"`  // 渠道方代码
	IV     string `json:"iv"`      // 加密密钥
	KEY    string `json:"key"`     // 加密密钥
	RsaPrk string `json:"rsa_prk"` // 私钥
	RsaNpk string `json:"rsa_npk"` // 回调公钥
}

func transformConfig(config *proto.Config) (*Config, error) {
	var extra ConfigExtra
	err := json.Unmarshal(config.Extra, &extra)
	if err != nil {
		return nil, err
	}
	return &Config{
		Config: config,
		Extra:  &extra,
	}, nil
}

func rechargeReq(in *proto.OrderRequest, chNlId string) *po.OrderReq {
	type Extra struct {
		OrderDt string `json:"orderDt"`
	}
	var e Extra
	_ = json.Unmarshal(in.Order.Extra, &e)

	return &po.OrderReq{
		Cmd:      "couponAcquire",
		AccessId: "UP",
		EntityTp: "03",

		ChNlId:      chNlId,
		Qid:         in.Order.OrderNo,
		OrderDt:     e.OrderDt,
		TraceId:     in.Order.OrderNo,
		DiscountId:  in.Product.ProductNo,
		Mobile:      in.Order.Account,
		DiscountNum: in.Order.Quantity,
	}
}

func rechargeResp(request *proto.OrderRequest, resp po.OrderResp) *proto.OrderResponse {
	data, _ := json.Marshal(resp)
	result := &proto.Result{
		OrderNo: request.Order.OrderNo,
		TradeNo: resp.CouponCd,
		Message: resp.Msg,
		Data:    data,
	}
	if !resp.Code.IsSuccess() {
		result.Status = proto.Status_FAIL
		result.Message = resp.GetMsg()
	} else {
		result.Status = proto.Status_ING
	}
	return &proto.OrderResponse{Result: result}
}
